pub struct VectorStoreFileObject {
pub id: String,
pub object: String,
pub usage_bytes: u64,
pub created_at: u64,
pub vector_store_id: String,
pub status: VectorStoreFileStatus,
pub last_error: Option<VectorStoreFileError>,
pub chunking_strategy: Option<ChunkingStrategyResponse>,
pub attributes: Option<VectorStoreFileAttributes>,
}vectorstore-types only.Fields
id: StringThe identifier, which can be referenced in API endpoints.
object: StringThe object type, which is always vector_store.file.
usage_bytes: u64The total vector store usage in bytes. Note that this may be different from the original file size.
created_at: u64The Unix timestamp (in seconds) for when the vector store file was created.
vector_store_id: StringThe ID of the vector store that the File is attached to.
status: VectorStoreFileStatusThe status of the vector store file, which can be either in_progress, completed,
cancelled, or failed. The status completed indicates that the vector store file is
ready for use.
last_error: Option<VectorStoreFileError>The last error associated with this vector store file. Will be null if there are no
errors.
chunking_strategy: Option<ChunkingStrategyResponse>The strategy used to chunk the file.
attributes: Option<VectorStoreFileAttributes>Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.