pub struct CreateVectorStoreFileBatchRequest {
pub file_ids: Option<Vec<String>>,
pub files: Option<Vec<CreateVectorStoreFileRequest>>,
pub chunking_strategy: Option<ChunkingStrategyRequestParam>,
pub attributes: Option<VectorStoreFileAttributes>,
}vectorstore-types only.Fields
file_ids: Option<Vec<String>>A list of File IDs that the vector store
should use. Useful for tools like file_search that can access files. If attributes or
chunking_strategy are provided, they will be applied to all files in the batch. Mutually
exclusive with files.
files: Option<Vec<CreateVectorStoreFileRequest>>A list of objects that each include a file_id plus optional attributes or
chunking_strategy. Use this when you need to override metadata for specific files.
The global attributes or chunking_strategy will be ignored and must be specified
for each file. Mutually exclusive with file_ids.
chunking_strategy: Option<ChunkingStrategyRequestParam>attributes: Option<VectorStoreFileAttributes>Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.